History
-------

.. to_doc


------------------
0.1.9 (02-05-2024)
------------------
* Fix release script if multiple bug fixes subheadings in changelog by @mvdbeek in https://github.com/galaxyproject/galaxy-release-util/pull/15

------------------
0.1.8 (02-05-2024)
------------------
* Add mypy to CI under python 3.8 by @jdavcs in https://github.com/galaxyproject/galaxy-release-util/pull/11
* Misc. updates  by @jdavcs in https://github.com/galaxyproject/galaxy-release-util/pull/12
* Misc. updates to script generating the release publication issue by @jdavcs in https://github.com/galaxyproject/galaxy-release-util/pull/13
* Fix link to docs on point releases by @jdavcs in https://github.com/galaxyproject/galaxy-release-util/pull/14

------------------
0.1.7 (21-02-2024)
------------------
* Misc. updates to script by @jdavcs in https://github.com/galaxyproject/galaxy-release-util/pull/9

------------------
0.1.6 (14-02-2024)
------------------
* Ignore commit without PR by @mvdbeek in https://github.com/galaxyproject/galaxy-release-util/pull/4
* Rename sections: "new things" > "things" by @jdavcs in https://github.com/galaxyproject/galaxy-release-util/pull/6
* Use semantic headings by @jdavcs in https://github.com/galaxyproject/galaxy-release-util/pull/5
* Ignore empty lines, comments when reading in packages_by_dep_dag.txt file by @jdavcs in https://github.com/galaxyproject/galaxy-release-util/pull/7
* Update release process template to current process by @mvdbeek in https://github.com/galaxyproject/galaxy-release-util/pull/8

------------------
0.1.5 (14-09-2023)
------------------
* Bootstrap history fixes for regenerating existing docs

------------------
0.1.4 (30-06-2023)
------------------
* Skip empty prerelease changelog when parsing changelog

------------------
0.1.3 (28-06-2023)
------------------
* Add step/checkbox on updating db revision identifier
* Bootstrap history fixes

------------------
0.1.2 (12-06-2023)
------------------
* Fix isinstance assertion

------------------
0.1.1 (12-06-2023)
------------------
* Add simplified makefile, development instruction
* Fix project description

------------------
0.1.0 (12-06-2023)
------------------

* Initial import from the Galaxy codebase
